bayespy.inference.vmp.nodes.bernoulli.BernoulliDistribution.plates_from_parent
==============================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.bernoulli

.. automethod:: BernoulliDistribution.plates_from_parent